@@ -1,4 +1,4 @@
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 knitr::opts_chunk$set(fig.width=8, fig.height=4)
 
 ## -----------------------------------------------------------------------------
@@ -8,14 +8,68 @@ library(photobiologyFilters)
 library(ggspectra)
 theme_set(theme_bw())
 
+## -----------------------------------------------------------------------------
+class(filters.mspct)
+
+## -----------------------------------------------------------------------------
+class(filters.mspct[[1]])
+
+## -----------------------------------------------------------------------------
+class(metals.mspct)
+
+## -----------------------------------------------------------------------------
+class(metals.mspct[[1]])
+
+## -----------------------------------------------------------------------------
+class(materials.mspct)
+
+## -----------------------------------------------------------------------------
+class(materials.mspct[[1]])
+
+## -----------------------------------------------------------------------------
+class(refractive_index.mspct)
+
+## -----------------------------------------------------------------------------
+class(refractive_index.mspct[[1]])
+
+## -----------------------------------------------------------------------------
+colnames(filters.mspct[[1]])
+
+## -----------------------------------------------------------------------------
+colnames(metals.mspct[[1]])
+
+## -----------------------------------------------------------------------------
+colnames(materials.mspct[[1]])
+
+## -----------------------------------------------------------------------------
+colnames(refractive_index.mspct[[1]])
+
 ## -----------------------------------------------------------------------------
 band_pass_filters
 
 ## -----------------------------------------------------------------------------
 schott_filters
 
+## ----eval=FALSE---------------------------------------------------------------
+#  help(schott_filters)
+
 ## -----------------------------------------------------------------------------
-head(names(filters.mspct), 6)
+names(metals.mspct)
+
+## -----------------------------------------------------------------------------
+names(materials.mspct)
+
+## -----------------------------------------------------------------------------
+names(refractive_index.mspct)
+
+## -----------------------------------------------------------------------------
+head(names(filters.mspct), 20)
+
+## -----------------------------------------------------------------------------
+if (utils::packageVersion('photobiology') > "0.10.4.9001") {
+  print(colnames(spct_metadata(filters.mspct[1:5])))
+  spct_metadata(filters.mspct[1:5])[ , c("spct.idx", "what.measured")]
+}
 
 ## -----------------------------------------------------------------------------
 filters.mspct$Schott_UG11
@@ -30,7 +84,7 @@ filters.mspct["Schott_UG11"]
 filters.mspct[petri_dishes]
 
 ## -----------------------------------------------------------------------------
-all_filter_accessors
+all_filter_selectors
 
 ## -----------------------------------------------------------------------------
 filters.mspct[grep("UG", names(filters.mspct))]
@@ -102,30 +156,41 @@ autoplot(thin_and_thick.mspct,
          span = 101)
 
 ## -----------------------------------------------------------------------------
-stack.spct <- filters.mspct$Haida_Clear_Night_NanoPro * filters.mspct$Firecrest_UVIR_Cut
+stack.spct <- filters.mspct$Haida_Clear_Night_NanoPro_1.6mm_52mm * filters.mspct$Firecrest_UVIR_Cut_0.96mm_52mm
                     
 autoplot(stack.spct,
          range = c(NA, 1400),
          w.band = c(UV_bands(), IR_bands("CIE")),
-         annotations = c("+", "boundaries", "wls"),
+         annotations = list(c("+", "boundaries"), c("-", "peaks")),
          span = 21) +
-  geom_line(data = filters.mspct$Haida_Clear_Night_NanoPro, colour = "purple") +
+  geom_line(data = filters.mspct$Haida_Clear_Night_NanoPro_1.6mm_52mm, colour = "purple") +
   geom_vline(xintercept = c(589, 589.6), linetype = "dotted") # Na emission lines
 
 ## -----------------------------------------------------------------------------
-ggplot(filters.mspct$Firecrest_UVIR_Cut) +
-  geom_line()
+ggplot(filters.mspct$Firecrest_UVIR_Cut_0.96mm_52mm) +
+  geom_line() +
+  scale_x_wl_continuous() +
+  scale_y_Tfr_total_continuous()
 
 ## -----------------------------------------------------------------------------
-transmittance(filters.mspct$Firecrest_UVIR_Cut, UVA())
+autoplot(metals.mspct$gold, range = c(NA, 800))
 
 ## -----------------------------------------------------------------------------
-absorbance(filters.mspct$Firecrest_UVIR_Cut, list(UVA(), NIR()))
+autoplot(materials.mspct$grass, range = c(NA, 800))
+
+## -----------------------------------------------------------------------------
+transmittance(filters.mspct$Firecrest_UVIR_Cut_0.96mm_52mm, UVA())
+
+## -----------------------------------------------------------------------------
+absorbance(filters.mspct$Firecrest_UVIR_Cut_0.96mm_52mm, list(UVA(), NIR()))
 
 ## -----------------------------------------------------------------------------
 transmittance(filters.mspct[grep("UG", names(filters.mspct))], 
               list(UVB(), UVA()))
 
+## -----------------------------------------------------------------------------
+reflectance(metals.mspct, w.band = VIS_bands())
+
 ## -----------------------------------------------------------------------------
 head(as.data.frame(filters.mspct$Schott_UG11))
 
